@@ -1,16 +1,16 @@
-# (C) Copyright IBM Corp. 2020.
+#  (C) Copyright IBM Corp. 2021.
 #
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
+#  Licensed under the Apache License, Version 2.0 (the "License");
+#  you may not use this file except in compliance with the License.
+#  You may obtain a copy of the License at
 #
-#      http://www.apache.org/licenses/LICENSE-2.0
+#       http://www.apache.org/licenses/LICENSE-2.0
 #
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+#  Unless required by applicable law or agreed to in writing, software
+#  distributed under the License is distributed on an "AS IS" BASIS,
+#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#  See the License for the specific language governing permissions and
+#  limitations under the License.
 
 import io
 import os
@@ -483,9 +483,12 @@ class Batch(BaseDeployment):
 
                     elif ((conn.type == DataConnectionTypes.DS or conn.type == DataConnectionTypes.CA) and
                           conn._check_if_connection_asset_is_s3()):
-                        conn._obm_cos_path = scoring_params['output_data_reference']['location']['path']
+                        if 'file_name' in scoring_params['output_data_reference']['location']:
+                            conn._obm_cos_path = scoring_params['output_data_reference']['location']['file_name']
+                        else:
+                            conn._obm_cos_path = scoring_params['output_data_reference']['location']['path']
 
-                return conn.read() # if in future output may be excel file or with custom separator, here it should be recognized
+                return conn.read(raw=True) # if in future output may be excel file or with custom separator, here it should be recognized
         else:
             raise MissingScoringResults(scoring_job_id, reason="Scoring is not completed.")
 
