@@ -380,6 +380,73 @@ class Deployments(WMLResource):
 
         return url
 
+    @docstring_parameter({'str_type': STR_TYPE_NAME})
+    def _get_serving_name_info(self, serving_name: str) -> tuple:
+        """
+           Get info about serving name.
+
+           **Parameters**
+
+           .. important::
+                #. **serving_name**: Serving name to filter deployments (optional)\n
+                   **type**: str\n
+
+           **Output**
+
+           .. important::
+                **returns**: information about serving name: (<status_code>, <response json if any>)\n
+                **return type**: tuple\n
+
+
+           **Example**
+
+            >>> is_available = client.deployments.is_serving_name_available('test')
+        """
+        params = {
+            'serving_name': serving_name,
+            'conflict': 'true',
+            'version': self._client.version_param
+        }
+
+        url = self._client.service_instance._href_definitions.get_deployments_href()
+        res = requests.get(url,
+                           headers=self._client._get_headers(),
+                           params=params,
+                           verify=not self._client.ICP)
+
+        if res.status_code == 409:
+            response = res.json()
+        else:
+            response = None
+
+        return (res.status_code, response)
+
+    @docstring_parameter({'str_type': STR_TYPE_NAME})
+    def is_serving_name_available(self, serving_name: str) -> bool:
+        """
+           Check if serving name is available for usage.
+
+           **Parameters**
+
+           .. important::
+                #. **serving_name**: Serving name to filter deployments (optional)\n
+                   **type**: str\n
+
+           **Output**
+
+           .. important::
+                **returns**: information if serving name is available\n
+                **return type**: bool\n
+
+
+           **Example**
+
+            >>> is_available = client.deployments.is_serving_name_available('test')
+        """
+        status_code, _ = self._get_serving_name_info(serving_name)
+
+        return status_code != 409
+
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_details(self, deployment_uid=None, serving_name=None, limit=None, asynchronous=False, get_all=False):
         """
@@ -432,47 +499,22 @@ class Deployments(WMLResource):
             raise WMLClientError(u'\'deployment_uid\' is not an uid: \'{}\''.format(deployment_uid))
 
         url = self._client.service_instance._href_definitions.get_deployments_href()
-        ## TODO:  Adding a work around till v4/deployment accepts space_id query parameter for GET
-        if self._ICP and not self._client.ICP_PLATFORM_SPACES:
-            if deployment_uid is not None:
-                url = url + '/' + deployment_uid
-                if self._client.ICP_35 or self._client.ICP_40:
-                    response = requests.get(
-                        url,
-                        params = self._client._params(),
-                        headers=self._client._get_headers(),
-                        verify=False
-                    )
-                else:
-                    response = requests.get(
-                        url,
-                        headers=self._client._get_headers(),
-                        verify=False
-                    )
-                return self._handle_response(200, "deployment", response)
-            else:
 
-                if asynchronous:
-                    return self._get_artifact_details(url, deployment_uid, limit, 'deployments',
-                                                      _async=asynchronous, _all=get_all)
+        query_params = self._client._params()
 
-                else:
-                    deployment_details = self._get_artifact_details(url, deployment_uid, limit, 'deployments',
-                                                                    _async=asynchronous, _all=get_all)
-                    if "system" in deployment_details:
-                        print("Note: " + deployment_details['system']['warnings'][0]['message'])
-                    return deployment_details
+        if serving_name:
+            query_params['serving_name'] = serving_name
+
+        if deployment_uid is None:
+            deployment_details = self._get_artifact_details(url, deployment_uid, limit, 'deployments', query_params=query_params,
+                                              _async=asynchronous, _all=get_all)
         else:
-            query_params = self._client._params()
-            if serving_name:
-                query_params['serving_name'] = serving_name
+            deployment_details = self._get_artifact_details(url, deployment_uid, limit, 'deployments', query_params=query_params)
 
-            if deployment_uid is None:
-                return self._get_artifact_details(url, deployment_uid, limit, 'deployments', query_params=query_params,
-                                                  _async=asynchronous, _all=get_all)
+        if "system" in deployment_details:
+            print("Note: " + deployment_details['system']['warnings'][0]['message'])
 
-            else:
-                return self._get_artifact_details(url, deployment_uid, limit, 'deployments', query_params=query_params)
+        return deployment_details
 
     @staticmethod
     @docstring_parameter({'str_type': STR_TYPE_NAME})
@@ -1134,11 +1176,8 @@ class Deployments(WMLResource):
 
         ## As auto_online_deployment and auto_redeploy values are passed as 'bool' but service needs them in 'str' format to patch.
         for ele in patch_payload:
-            if('auto_online_deployment' in ele['path'] or 'auto_redeploy' in ele['path']):
-                if(ele['value']==True):
-                    ele['value']='true'
-                else:
-                    ele['value']='false'
+            if 'auto_online_deployment' in ele['path'] or 'auto_redeploy' in ele['path']:
+                ele['value'] = str(ele['value']).lower()
 
         url = self._client.service_instance._href_definitions.get_deployment_href(deployment_uid)
 
