@@ -303,6 +303,44 @@ class AutoAI(BaseExperiment):
             Number of maximum parallel connection to data source.
             Supported only for IBM Cloud Pak® for Data 4.0.1 and above.
 
+        categorical_imputation_strategy: ImputationStrategy, optional
+            Missing values imputation strategy for categorical columns.
+
+            Possible values (only non-forecasting scenario):
+            - ImputationStrategy.MEAN
+            - ImputationStrategy.MEDIAN
+            - ImputationStrategy.MOST_FREQUENT (default)
+
+
+        numerical_imputation_strategy: ImputationStrategy, optional
+            Missing values imputation strategy for numerical columns.
+
+            Possible values (non-forecasting scenario):
+            - ImputationStrategy.MEAN
+            - ImputationStrategy.MEDIAN (default)
+            - ImputationStrategy.MOST_FREQUENT
+
+            Possible values (forecasting scenario):
+            - ImputationStrategy.MEAN
+            - ImputationStrategy.MEDIAN
+            - ImputationStrategy.BEST_OF_DEFAULT_IMPUTERS (default)
+            - ImputationStrategy.VALUE
+            - ImputationStrategy.FLATTEN_ITERATIVE
+            - ImputationStrategy.LINEAR
+            - ImputationStrategy.CUBIC
+            - ImputationStrategy.PREVIOUS
+            - ImputationStrategy.NEXT
+            - ImputationStrategy.NO_IMPUTATION
+
+
+        numerical_imputation_value: float, optional
+            Value for filling missing values if numerical_imputation_strategy is set to ImputationStrategy.VALUE.
+            For forecasting only.
+
+        imputation_threshold: float, optional
+            Maximum threshold of missing values imputation.
+            For forecasting only.
+
         retrain_on_holdout: bool, optional
             If True final pipelines will be train also on holdout data.
 
@@ -361,9 +399,8 @@ class AutoAI(BaseExperiment):
             raise TSNotSupported()
 
         if prediction_type == PredictionType.FORECASTING:
-            # TODO uncomment when TS will support imputation
-            # if not numerical_imputation_strategy:
-            #     numerical_imputation_strategy = ImputationStrategy.BEST_OF_DEFAULT_IMPUTERS
+            if not numerical_imputation_strategy:
+                numerical_imputation_strategy = ImputationStrategy.BEST_OF_DEFAULT_IMPUTERS
 
             if prediction_column is not None or prediction_columns is None:
                 raise ForecastPredictionColumnsMissing()
