@@ -1,16 +1,16 @@
-# (C) Copyright IBM Corp. 2020.
+#  (C) Copyright IBM Corp. 2021.
 #
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
+#  Licensed under the Apache License, Version 2.0 (the "License");
+#  you may not use this file except in compliance with the License.
+#  You may obtain a copy of the License at
 #
-#      http://www.apache.org/licenses/LICENSE-2.0
+#       http://www.apache.org/licenses/LICENSE-2.0
 #
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+#  Unless required by applicable law or agreed to in writing, software
+#  distributed under the License is distributed on an "AS IS" BASIS,
+#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#  See the License for the specific language governing permissions and
+#  limitations under the License.
 
 import os
 
@@ -36,6 +36,7 @@ from ibm_watson_machine_learning.utils.autoai.wsd_ui import (
     save_computed_pipelines_for_ui, save_experiment_for_ui, save_metadata_for_ui)
 from ibm_watson_machine_learning.utils.autoai.connection import validate_source_data_connections, \
     validate_results_data_connection
+from ibm_watson_machine_learning.utils import DisableWarningsLogger
 from .base_auto_pipelines import BaseAutoPipelines
 
 if TYPE_CHECKING:
@@ -155,7 +156,12 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                  test_data_excel_sheet: Union[str, int] = 0,
                  test_data_encoding: str = 'utf-8',
                  # sampling_type=None,  #TODO: Uncomment to add sampling_type support
-                 # fairness_info=None,  TODO: uncomment to add fairness info
+                 categorical_imputation_strategy=None,
+                 numerical_imputation_strategy=None,
+                 numerical_imputation_value=None,
+                 imputation_threshold=None,
+                 fairness_info: dict = None,
+                 retrain_on_holdout: bool = True,
                  **kwargs):
         self.params = {
             'name': name,
@@ -185,7 +191,6 @@ class RemoteAutoPipelines(BaseAutoPipelines):
             'notebooks': notebooks,
             'autoai_pod_version': autoai_pod_version,
             'obm_pod_version': obm_pod_version,
-            # 'fairness_info': fairness_info, TODO: uncomment to add fairness info
             'text_processing': text_processing,
             'word2vec_feature_number': word2vec_feature_number,
             'daub_give_priority_to_runtime': daub_give_priority_to_runtime,
@@ -195,7 +200,16 @@ class RemoteAutoPipelines(BaseAutoPipelines):
             'test_data_csv_separator': test_data_csv_separator,
             'test_data_excel_sheet': test_data_excel_sheet,
             'test_data_encoding': test_data_encoding,
+            'categorical_imputation_strategy': categorical_imputation_strategy,
+            'numerical_imputation_strategy': numerical_imputation_strategy,
+            'numerical_imputation_value': numerical_imputation_value,
+            'imputation_threshold': imputation_threshold,
+            'retrain_on_holdout': retrain_on_holdout
         }
+
+        if fairness_info:
+            self.params['fairness_info'] = fairness_info
+
         self._engine: 'WMLEngine' = engine
         self._engine.initiate_remote_resources(params=self.params, **kwargs)
         self.best_pipeline = None
@@ -255,17 +269,22 @@ class RemoteAutoPipelines(BaseAutoPipelines):
     def fit(self,
             train_data: 'DataFrame' = None,
             *,
-            training_data_reference: List['DataConnection'],
+            training_data_reference: List['DataConnection'] = None,
             training_results_reference: 'DataConnection' = None,
             background_mode=False,
-            test_data_references: List['DataConnection'] = None) -> dict:
+            test_data_references: List['DataConnection'] = None,
+            training_data_references: List['DataConnection'] = None) -> dict:
         """
         Run a training process on WML of autoai on top of the training data referenced by DataConnection.
 
         Parameters
         ----------
-        training_data_reference: List[DataConnection], required
+        training_data_reference: List[DataConnection], optional
+            Data storage connection details to inform where training data is stored. (Old parameter)
+
+        training_data_references: List[DataConnection], required
             Data storage connection details to inform where training data is stored.
+            New version of `training_data_reference`
 
         training_results_reference: DataConnection, optional
             Data storage connection details to store pipeline training results. Not applicable on CP4D.
@@ -311,13 +330,15 @@ class RemoteAutoPipelines(BaseAutoPipelines):
         >>>     ),
         >>>     background_mode=False)
         """
+        if training_data_references is not None:
+            training_data_reference = training_data_references
 
-        if None in training_data_reference:
-            raise NoneDataConnection('training_data_reference')
+        if training_data_reference is None or not training_data_reference:
+            raise NoneDataConnection('training_data_references')
 
         for conn in training_data_reference:
             if self._workspace.wml_client.project_type == 'local_git_storage':
-                conn.location.userfs = True
+                conn.location.userfs = 'true'
             conn._wml_client = self._workspace.wml_client
             # TODO: remove S3 implementation
             if conn.type == DataConnectionTypes.S3:
@@ -331,7 +352,7 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                 # Update test data ref with client object, experiment parameters
                 if isinstance(conn, DataConnection):
                     if self._workspace.wml_client.project_type == 'local_git_storage':
-                        conn.location.userfs = True
+                        conn.location.userfs = 'true'
                     conn._wml_client = self._workspace.wml_client
                     # TODO: remove S3 implementation
                     if conn.type == DataConnectionTypes.S3:
@@ -448,6 +469,11 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                                       background_mode=background_mode,
                                       test_data_references=test_data_references)
 
+        for conn in training_data_reference:
+            metrics = run_params['entity']['status'].get('metrics', [])
+            if metrics and metrics[-1]['context'].get('fairness'):
+                conn.auto_pipeline_params['fairness_info'] = metrics[-1]['context']['fairness'].get('info')
+
         if isinstance(training_data_reference[0].location, WSDAssetLocation) or (
                 isinstance(training_data_reference[0].location, AssetLocation
                            ) and training_data_reference[0].location._wsd):
@@ -491,10 +517,15 @@ class RemoteAutoPipelines(BaseAutoPipelines):
         """
         return self._engine.get_run_status()
 
-    def get_run_details(self) -> dict:
+    def get_run_details(self, include_metrics: bool = False) -> dict:
         """
         Get fit/run details.
 
+        Parameters
+        ----------
+        include_metrics: bool, optional
+            Indicates to include metrics in the training details output. Default False.
+
         Returns
         -------
         Dictionary with AutoPipelineOptimizer fit/run details.
@@ -507,7 +538,7 @@ class RemoteAutoPipelines(BaseAutoPipelines):
         >>>
         >>> remote_optimizer.get_run_details()
         """
-        return self._engine.get_run_details()
+        return self._engine.get_run_details(include_metrics=include_metrics)
 
     def cancel_run(self) -> None:
         """Cancels an AutoAI run."""
@@ -702,8 +733,9 @@ class RemoteAutoPipelines(BaseAutoPipelines):
         """
         user_holdout_exists = True
         try:
-            with redirect_stdout(open(os.devnull, "w")):
-                self.get_test_data_connections()
+            with DisableWarningsLogger():
+                with redirect_stdout(open(os.devnull, "w")):
+                    self.get_test_data_connections()
 
         except TestDataNotPresent:
             user_holdout_exists = False
@@ -714,12 +746,18 @@ class RemoteAutoPipelines(BaseAutoPipelines):
         data_connections = [
             DataConnection._from_dict(_dict=data_connection) for data_connection in training_data_references]
 
+        run_details = self.get_run_details(include_metrics=True)
+
         for data_connection in data_connections:  # note: populate DataConnections with optimizer params
             data_connection.auto_pipeline_params = deepcopy(optimizer_parameters)
             data_connection._wml_client = self._engine._wml_client
             data_connection._run_id = self._engine._current_run_id
             data_connection._user_holdout_exists = user_holdout_exists
 
+            metrics = run_details['entity']['status'].get('metrics', [])
+            if metrics and metrics[-1]['context'].get('fairness'):
+                data_connection.auto_pipeline_params['fairness_info'] = metrics[-1]['context']['fairness'].get('info')
+
         return data_connections
 
     def get_test_data_connections(self) -> List['DataConnection']:
