@@ -100,20 +100,24 @@ class AutoPipelinesRuns(BaseAutoPipelinesRuns):
             wml_pipelines_types.append(wml_pipeline_type)
 
         if self.auto_pipeline_optimizer_name is not None:
-            values = [[timestamp, run['metadata'].get('id', run['metadata'].get('guid')), run['entity']['status']['state'], wml_pipeline_name] for
-                      timestamp, run, wml_pipeline_name, wml_pipeline_type in zip(runs_timestamps,
-                                                                                  data,
-                                                                                  wml_pipelines_names,
-                                                                                  wml_pipelines_types)
-                      if wml_pipeline_name == self.auto_pipeline_optimizer_name and wml_pipeline_type == 'autoai']
+            values = [
+                [timestamp, run['metadata'].get('id', run['metadata'].get('guid')), run['entity']['status']['state'],
+                 wml_pipeline_name] for
+                timestamp, run, wml_pipeline_name, wml_pipeline_type in zip(runs_timestamps,
+                                                                            data,
+                                                                            wml_pipelines_names,
+                                                                            wml_pipelines_types)
+                if wml_pipeline_name == self.auto_pipeline_optimizer_name and wml_pipeline_type == 'autoai']
 
         else:
-            values = [[timestamp, run['metadata'].get('id', run['metadata'].get('guid')), run['entity']['status']['state'], wml_pipeline_name] for
-                      timestamp, run, wml_pipeline_name, wml_pipeline_type in zip(runs_timestamps,
-                                                                                  data,
-                                                                                  wml_pipelines_names,
-                                                                                  wml_pipelines_types)
-                      if wml_pipeline_type == 'autoai']
+            values = [
+                [timestamp, run['metadata'].get('id', run['metadata'].get('guid')), run['entity']['status']['state'],
+                 wml_pipeline_name] for
+                timestamp, run, wml_pipeline_name, wml_pipeline_type in zip(runs_timestamps,
+                                                                            data,
+                                                                            wml_pipelines_names,
+                                                                            wml_pipelines_types)
+                if wml_pipeline_type == 'autoai']
 
         runs = DataFrame(data=values, columns=columns)
         return runs.sort_values(by=["timestamp"], ascending=False)
@@ -171,6 +175,11 @@ class AutoPipelinesRuns(BaseAutoPipelinesRuns):
                                                                          optimizer_config=optimizer_config)
         # --- end note
 
+        # note: try to find ts node
+        ts_node_number, ts_runtime_number = get_node_and_runtime_index(node_name='ts',
+                                                                       optimizer_config=optimizer_config)
+        # --- end note
+
         try:
             name = optimizer_config['entity']['name']
             description = optimizer_config['entity'].get('description', '')
@@ -222,16 +231,41 @@ class AutoPipelinesRuns(BaseAutoPipelinesRuns):
                 params['train_sample_rows_test_size'] = kb_parameters['train_sample_rows_test_size']
             if kb_parameters.get('scorer_for_ranking'):
                 params['scoring'] = kb_parameters['scorer_for_ranking']
-            if kb_parameters.get('text_processing_options') and kb_parameters['text_processing_options'].get('word2vec'):
-                params['word2vec_feature_number'] = kb_parameters['text_processing_options']['word2vec'].get('output_dim')
+            if kb_parameters.get('text_processing_options') and kb_parameters['text_processing_options'].get(
+                    'word2vec'):
+                params['word2vec_feature_number'] = kb_parameters['text_processing_options']['word2vec'].get(
+                    'output_dim')
             if kb_parameters.get('fairness_info'):
                 params['fairness_info'] = kb_parameters.get('fairness_info')
-            if kb_parameters['learning_type'] == 'timeseries':
-                params['backtest_num'] = kb_parameters.get('backtest_num')
-                params['lookback_window'] = kb_parameters.get('lookback_window')
-                params['forecast_window'] = kb_parameters.get('forecast_window')
-                params['backtest_gap_length'] = kb_parameters.get('backtest_gap_length')
-                params['include_only_estimators'] = kb_parameters.get('include_only_estimators')
+        elif ts_node_number is not None:
+            ts_parameters = optimizer_config['entity']['document']['pipelines'][0]['nodes'][ts_node_number][
+                'parameters']['optimization']
+            ts_wml_data = optimizer_config['entity']['document']['runtimes'][ts_node_number]['app_data']['wml_data']
+
+            csv_separator = optimizer_config['entity']['document']['pipelines'][0]['nodes'][ts_node_number][
+                'parameters'].get('input_file_separator', ',')
+            encoding = optimizer_config['entity']['document']['pipelines'][0]['nodes'][ts_node_number][
+                'parameters'].get('encoding', 'utf-8')
+
+            params = {
+                'name': name,
+                'desc': description,
+                'prediction_type': ts_parameters['learning_type'],
+                'prediction_column': ts_parameters.get('label'),
+                'prediction_columns': ts_parameters.get('target_columns'),
+                'timestamp_column_name': ts_parameters.get('timestamp_column'),
+                'holdout_size': ts_parameters['holdout_param'],
+                'max_num_daub_ensembles': ts_parameters['max_num_daub_ensembles'],
+                'backtest_gap_length': ts_parameters.get('backtest_gap_length'),
+                'backtest_num': ts_parameters.get('backtest_num'),
+                'forecast_window': ts_parameters.get('forecast_window'),
+                'include_only_estimators': ts_parameters.get('include_only_estimators'),
+                'lookback_window': ts_parameters.get('lookback_window'),
+                't_shirt_size': ts_wml_data['hardware_spec']['id'],
+                'csv_separator': csv_separator,
+                'encoding': encoding,
+            }
+
         else:
             params = {
                 'name': name,
@@ -296,7 +330,7 @@ class AutoPipelinesRuns(BaseAutoPipelinesRuns):
 
     def get_optimizer(self,
                       run_id: Optional[str] = None,
-                      metadata: Dict[str, Union[List['DataConnection'],  'DataConnection', str, int]] = None
+                      metadata: Dict[str, Union[List['DataConnection'], 'DataConnection', str, int]] = None
                       ) -> 'RemoteAutoPipelines':
         """
         Creates instance of AutoPipelinesRuns with all computed pipelines computed by AutoAi on WML.
