@@ -515,7 +515,8 @@ class DataConnection(BaseDataConnection):
         if experiment_metadata is not None:
             self.auto_pipeline_params['train_sample_rows_test_size'] = experiment_metadata.get(
                 'train_sample_rows_test_size')
-            self.auto_pipeline_params['prediction_column'] = experiment_metadata['prediction_column']
+            self.auto_pipeline_params['prediction_column'] = experiment_metadata.get('prediction_column')
+            self.auto_pipeline_params['prediction_columns'] = experiment_metadata.get('prediction_columns')
             self.auto_pipeline_params['holdout_size'] = experiment_metadata.get('holdout_size')
             self.auto_pipeline_params['prediction_type'] = experiment_metadata['prediction_type']
             self.auto_pipeline_params['fairness_info'] = experiment_metadata.get('fairness_info')
@@ -1051,7 +1052,8 @@ class AssetLocation(BaseLocation):
         try:
             from project_lib import Project
             try:
-                access = Project.access()
+                with all_logging_disabled():
+                    access = Project.access()
                 return True
             except RuntimeError:
                 pass
