@@ -455,7 +455,10 @@ class RemoteTrainingSystem(WMLResource):
          >>>     wml_client.remote_training_systems.ConfigurationMetaNames.LOCAL_TRAINING: {
          >>>        "name": "LocalTrainingHandler",
          >>>        "path": "ibmfl.party.training.local_training_handler"
-         >>>     }
+         >>>     },
+         >>>     wml_client.remote_training_systems.ConfigurationMetaNames.HYPERPARAMS: {
+         >>>        "epochs": 3
+         >>>     },
          >>> }
          >>> party = client.remote_training_systems.create_party(remote_training_system_id, party_metadata)
 
@@ -485,4 +488,7 @@ class RemoteTrainingSystem(WMLResource):
         if "local_training" in party_metadata:
             party_config["local_training"] = party_metadata[self._client.remote_training_systems.ConfigurationMetaNames.LOCAL_TRAINING]
 
-        return Party(client=self._client, config_dict=party_config)
\ No newline at end of file
+        if "hyperparams" in party_metadata:
+            party_config["hyperparams"] = party_metadata[self._client.remote_training_systems.ConfigurationMetaNames.HYPERPARAMS]
+
+        return Party(client=self._client, config_dict=party_config)
