@@ -13,6 +13,7 @@
 #  limitations under the License.
 
 import abc
+import uuid
 from os import environ
 
 import unittest
@@ -22,6 +23,7 @@ from sklearn.pipeline import Pipeline
 from ibm_watson_machine_learning import APIClient
 from ibm_watson_machine_learning.experiment import AutoAI
 from ibm_watson_machine_learning.deployment import WebService, Batch
+from ibm_watson_machine_learning.utils.deployment.errors import ServingNameNotAvailable
 from ibm_watson_machine_learning.workspace import WorkSpace
 from ibm_watson_machine_learning.helpers.connections import DataConnection
 from ibm_watson_machine_learning.experiment.autoai.optimizers import RemoteAutoPipelines
@@ -56,6 +58,10 @@ class AbstractTestWebservice(abc.ABC):
 
     X_df = None
 
+    initial_deployment_serving_name = 'depl_serving_name_init_' + str(uuid.uuid4())[:8]
+    deployment_serving_name = 'depl_serving_name_' + str(uuid.uuid4())[:8]
+    deployment_serving_name_patch = 'depl_serving_name_patch_' + str(uuid.uuid4())[:8]
+
     @abc.abstractmethod
     def test_00a_space_cleanup(self):
         pass
@@ -92,16 +98,69 @@ class AbstractTestWebservice(abc.ABC):
     def test_32__deploy__deploy_best_computed_pipeline_from_autoai_on_wml(self):
         best_pipeline = self.remote_auto_pipelines.summary()._series['Enhancements'].keys()[0]
         print('Deploying', best_pipeline)
+
+        self.assertTrue(self.wml_client.deployments.is_serving_name_available(
+            serving_name=AbstractTestWebservice.initial_deployment_serving_name))
+
         AbstractTestWebservice.service.create(
             experiment_run_id=self.remote_auto_pipelines._engine._current_run_id,
             model=best_pipeline,
-            deployment_name=self.DEPLOYMENT_NAME)
+            deployment_name=self.DEPLOYMENT_NAME,
+            serving_name=AbstractTestWebservice.initial_deployment_serving_name
+        )
+
+        self.assertFalse(self.wml_client.deployments.is_serving_name_available(
+            serving_name=AbstractTestWebservice.initial_deployment_serving_name))
+
+        with self.assertRaises(ServingNameNotAvailable):
+            service = WebService(source_wml_credentials=self.wml_credentials,
+                                 source_space_id=self.space_id,
+                                 target_wml_credentials=self.wml_credentials,
+                                 target_space_id=self.space_id)
+
+            service.create(
+                experiment_run_id=self.remote_auto_pipelines._engine._current_run_id,
+                model=best_pipeline,
+                deployment_name=self.DEPLOYMENT_NAME,
+                serving_name=AbstractTestWebservice.initial_deployment_serving_name
+            )
 
         self.assertIsNotNone(AbstractTestWebservice.service.id, msg="Online Deployment creation - missing id")
         self.assertIsNotNone(AbstractTestWebservice.service.name, msg="Online Deployment creation - name not set")
         self.assertIsNotNone(AbstractTestWebservice.service.scoring_url,
                              msg="Online Deployment creation - mscoring url  missing")
 
+    def test_32b_serving_name_test(self):
+        self.target_space_id = self.space_id
+        self.wml_client.set.default_space(self.target_space_id)
+
+        deployment_details = self.wml_client.deployments.get_details(serving_name='non_existing')
+        self.assertTrue(len(deployment_details['resources']) == 0)
+
+        self.wml_client.deployments.update(AbstractTestWebservice.service.deployment_id, {
+            self.wml_client.deployments.ConfigurationMetaNames.SERVING_NAME: self.deployment_serving_name})
+
+        deployment_details = self.wml_client.deployments.get_details(serving_name=self.deployment_serving_name)
+        self.assertTrue(len(deployment_details['resources']) == 1)
+
+        self.assertTrue(
+            str(self.wml_client.deployments.get_serving_href(deployment_details['resources'][0])).endswith(
+                f'/{self.deployment_serving_name}/predictions'))
+
+        self.wml_client.deployments.update(AbstractTestWebservice.service.deployment_id,
+                                           {'serving_name': self.deployment_serving_name_patch})
+
+        deployment_details = self.wml_client.deployments.get_details(serving_name=self.deployment_serving_name)
+        self.assertTrue(len(deployment_details['resources']) == 0)
+
+        deployment_details = self.wml_client.deployments.get_details(
+            serving_name=self.deployment_serving_name_patch)
+        self.assertTrue(len(deployment_details['resources']) == 1)
+
+        self.assertTrue(
+            str(self.wml_client.deployments.get_serving_href(deployment_details['resources'][0])).endswith(
+                f'/{self.deployment_serving_name_patch}/predictions'))
+
     def test_33_score_deployed_model(self):
         nb_records = 5
         predictions = AbstractTestWebservice.service.score(payload=self.X_df[:nb_records])
