@@ -216,11 +216,10 @@ class AbstractTestTSAsync(abc.ABC):
         self.assertIsNotNone(metrics)
         self.assertGreater(len(metrics), 0)
 
-    # # GET PIPELINE FOR TS IS NOT SUPPORTED
-    # def test_09_predict_using_fitted_pipeline(self):
-    #     predictions = self.remote_auto_pipelines.predict(X=self.X_values)
-    #     print(predictions)
-    #     self.assertGreater(len(predictions), 0)
+    def test_09_predict_using_fitted_pipeline(self):
+        predictions = self.remote_auto_pipelines.predict(X=self.train_data[:5])
+        print(predictions)
+        self.assertGreater(len(predictions), 0)
 
     def test_10_summary_listing_all_pipelines_from_wml(self):
         pipelines_summary = self.remote_auto_pipelines.summary()
@@ -251,11 +250,11 @@ class AbstractTestTSAsync(abc.ABC):
     # # LALE #
     # ########
     #
-    # def test_13_get_pipeline__load_lale_pipeline__pipeline_loaded(self):
-    #     AbstractTestTSAsync.lale_pipeline = self.remote_auto_pipelines.get_pipeline()
-    #     print(f"Fetched pipeline type: {type(self.lale_pipeline)}")
-    #     from lale.operators import TrainablePipeline
-    #     self.assertIsInstance(self.lale_pipeline, TrainablePipeline)
+    def test_13_get_pipeline__load_lale_pipeline__pipeline_loaded(self):
+        AbstractTestTSAsync.lale_pipeline = self.remote_auto_pipelines.get_pipeline()
+        print(f"Fetched pipeline type: {type(self.lale_pipeline)}")
+        from lale.operators import TrainablePipeline
+        self.assertIsInstance(self.lale_pipeline, TrainablePipeline)
     #
     # def test_14_get_all_pipelines_as_lale(self):
     #     get_and_predict_all_pipelines_as_lale(self.remote_auto_pipelines, self.X_values)
