@@ -1,3 +1,17 @@
+#  (C) Copyright IBM Corp. 2021.
+#
+#  Licensed under the Apache License, Version 2.0 (the "License");
+#  you may not use this file except in compliance with the License.
+#  You may obtain a copy of the License at
+#
+#       http://www.apache.org/licenses/LICENSE-2.0
+#
+#  Unless required by applicable law or agreed to in writing, software
+#  distributed under the License is distributed on an "AS IS" BASIS,
+#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#  See the License for the specific language governing permissions and
+#  limitations under the License.
+
 import unittest
 from sklearn.pipeline import Pipeline
 from pprint import pprint
@@ -23,7 +37,7 @@ from ibm_watson_machine_learning.tests.utils.cleanup import space_cleanup, delet
 
 from ibm_watson_machine_learning.utils.autoai.enums import PositiveLabelClass, TShirtSize, Transformers
 
-
+@unittest.skip("S3 type no longer supported")
 class TestAutoAIRemote(unittest.TestCase):
     """
     The test can be run on CLOUD, WMLS and CPD (not tested)
