@@ -118,7 +118,10 @@ class TestAutoAIRemote(AbstractTestAutoAIRemote, unittest.TestCase):
         self.assertRaises(NotImplementedError, self.data_connection.read)
 
     def test_06b_get_train_data(self):  # test data
-        X_test, y_test = self.remote_auto_pipelines.get_test_data_connections()[0].read()
+        test_df = self.remote_auto_pipelines.get_test_data_connections()[0].read()
+
+        X_test = test_df.drop([self.prediction_column], axis=1).values
+        y_test = test_df[self.prediction_column].values
 
         print("Test data sample:")
         print(X_test)
