@@ -104,34 +104,6 @@ class TestAutoAIRemote(AbstractTestAutoAISync, AbstractTestWebservice, AbstractT
         self.assertIsNotNone(obj=TestAutoAIRemote.data_connection)
         self.assertIsNone(obj=TestAutoAIRemote.results_connection)
 
-    def test_32b_serving_name_test(self):
-        self.target_space_id = self.space_id
-        self.wml_client.set.default_space(self.target_space_id)
-
-        deployment_details = self.wml_client.deployments.get_details(serving_name='non_existing')
-        self.assertTrue(len(deployment_details['resources']) == 0)
-
-        self.wml_client.deployments.update(TestAutoAIRemote.service.deployment_id, {
-            self.wml_client.deployments.ConfigurationMetaNames.SERVING_NAME: self.deployment_serving_name})
-
-        deployment_details = self.wml_client.deployments.get_details(serving_name=self.deployment_serving_name)
-        self.assertTrue(len(deployment_details['resources']) == 1)
-
-        self.assertTrue(str(self.wml_client.deployments.get_serving_href(deployment_details['resources'][0])).endswith(
-            f'/{self.deployment_serving_name}/predictions'))
-
-        self.wml_client.deployments.update(self.service.deployment_id,
-                                           {'serving_name': self.deployment_serving_name_patch})
-
-        deployment_details = self.wml_client.deployments.get_details(serving_name=self.deployment_serving_name)
-        self.assertTrue(len(deployment_details['resources']) == 0)
-
-        deployment_details = self.wml_client.deployments.get_details(serving_name=self.deployment_serving_name_patch)
-        self.assertTrue(len(deployment_details['resources']) == 1)
-
-        self.assertTrue(str(self.wml_client.deployments.get_serving_href(deployment_details['resources'][0])).endswith(
-            f'/{self.deployment_serving_name_patch}/predictions'))
-
     def test_99_delete_connection_and_connected_data_asset(self):
         if not self.SPACE_ONLY:
             self.wml_client.set.default_project(self.project_id)
