@@ -1,16 +1,16 @@
-# (C) Copyright IBM Corp. 2020.
+#  (C) Copyright IBM Corp. 2021.
 #
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
+#  Licensed under the Apache License, Version 2.0 (the "License");
+#  you may not use this file except in compliance with the License.
+#  You may obtain a copy of the License at
 #
-#      http://www.apache.org/licenses/LICENSE-2.0
+#       http://www.apache.org/licenses/LICENSE-2.0
 #
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+#  Unless required by applicable law or agreed to in writing, software
+#  distributed under the License is distributed on an "AS IS" BASIS,
+#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#  See the License for the specific language governing permissions and
+#  limitations under the License.
 
 from __future__ import print_function
 import requests
@@ -88,7 +88,8 @@ class Training(WMLResource):
             raise WMLClientError(u'Getting trained model status failed. Unable to get model details for training_uid: \'{}\'.'.format(training_uid))
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
-    def get_details(self, training_uid=None, limit=None, asynchronous=False, get_all=False):
+    def get_details(self, training_uid=None, limit=None, asynchronous=False, get_all=False, training_type=None,
+                    state=None, tag_value=None, training_definition_id=None):
         """
         Get metadata of training(s). If training_uid is not specified returns all model spaces metadata.
 
@@ -103,6 +104,18 @@ class Training(WMLResource):
                **type**: bool\n
             #. **get_all**:  if True, it will get all entries in 'limited' chunks (optional)\n
                **type**: bool\n
+            #. **training_type**: Filter the fetched list of trainings based on training type
+                                  [`pipeline` or `experiment`] (optional)\n
+               **type**: str\n
+            #. **state**: Filter the fetched list of training based on their state:
+                          [`queued`, `running`, `completed`, `failed`] (optional)\n
+               **type**: str\n
+            #. **tag_value**: Filter the fetched list of training based on ther tag value (optional)\n
+               **type**: str\n
+            #. **training_definition_id**: Filter the fetched trainings which are using the given training_definition
+                                           (optional)\n
+               **type**: str\n
+
 
         **Output**
 
@@ -132,8 +145,20 @@ class Training(WMLResource):
         url = self._client.service_instance._href_definitions.get_trainings_href()
 
         if training_uid is None:
-            return self._get_artifact_details(url, training_uid, limit, 'trained models', _async=asynchronous, _all=get_all)
+            query_params = {
+                param_name: param_value
+                for param_name, param_value in (
+                    ('type', training_type),
+                    ('state', state),
+                    ('tag.value', tag_value),
+                    ('training_definition_id', training_definition_id)
+                ) if param_value is not None
+            }
+            # note: If query params is an empty dict convert it back to None value
+            query_params = query_params if query_params != {} else None
 
+            return self._get_artifact_details(url, training_uid, limit, 'trained models', _async=asynchronous,
+                                              _all=get_all, query_params=query_params)
         else:
             return self._get_artifact_details(url, training_uid, limit, 'trained models')
 
@@ -353,6 +378,10 @@ class Training(WMLResource):
             u'training_data_references': meta_props[self.ConfigurationMetaNames.TRAINING_DATA_REFERENCES],
             u'results_reference': meta_props[self.ConfigurationMetaNames.TRAINING_RESULTS_REFERENCE]
         }
+
+        if self.ConfigurationMetaNames.TEST_DATA_REFERENCES in meta_props:
+            training_configuration_metadata['test_data_references'] = meta_props[self.ConfigurationMetaNames.TEST_DATA_REFERENCES]
+
         if self.ConfigurationMetaNames.TAGS in meta_props:
             training_configuration_metadata["tags"] = meta_props[self.ConfigurationMetaNames.TAGS]
 
@@ -1098,4 +1127,4 @@ class Training(WMLResource):
 
             latest_metrics.append(sorted_value[-1])
 
-        return latest_metrics
\ No newline at end of file
+        return latest_metrics
