@@ -370,23 +370,22 @@ class WrongModelName(WMLClientError, ValueError):
 class StrategyIsNotApplicable(WMLClientError, ValueError):
     def __init__(self, strategy, prediction_type, valid_strategies):
         WMLClientError.__init__(self,
-                                f'{strategy} is not applicable for '
+                                f'{strategy} is not valid for '
                                 f'{"forecasting" if prediction_type == PredictionType.FORECASTING else "non-forecasting"} '
-                                f'scenario. List of valid strategies is: {", ".join(valid_strategies)}')
+                                f'scenario. Valid strategies are: {", ".join(valid_strategies)}')
 
 
 class NumericalImputationStrategyValueMisused(WMLClientError, ValueError):
     def __init__(self):
-        WMLClientError.__init__(self, 'Parameter `numerical_imputation_value` can be only used when '
+        WMLClientError.__init__(self, 'Parameter `numerical_imputation_value` can only be used when '
                                       '`numerical_imputation_strategy` is set to ImputationStrategy.VALUE.')
 
 
 class InvalidImputationParameterNonTS(WMLClientError, ValueError):
     def __init__(self):
-        WMLClientError.__init__(self, '`numerical_imputation_value` and `imputation_threshold` can be set only'
-                                      ' in forecasting scenario.')
+        WMLClientError.__init__(self, '`numerical_imputation_value` and `imputation_threshold` can be set only for forecasting experiments.')
 
 
 class InvalidImputationParameterTS(WMLClientError, ValueError):
     def __init__(self):
-        WMLClientError.__init__(self, 'For forecasting scenario `categorical_imputation_strategy` should not be set.')
+        WMLClientError.__init__(self, '`categorical_imputation_strategy` does not apply to a forecasting experiment.')
