@@ -1,16 +1,16 @@
-# (C) Copyright IBM Corp. 2020.
+#  (C) Copyright IBM Corp. 2021.
 #
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
+#  Licensed under the Apache License, Version 2.0 (the "License");
+#  you may not use this file except in compliance with the License.
+#  You may obtain a copy of the License at
 #
-#      http://www.apache.org/licenses/LICENSE-2.0
+#       http://www.apache.org/licenses/LICENSE-2.0
 #
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+#  Unless required by applicable law or agreed to in writing, software
+#  distributed under the License is distributed on an "AS IS" BASIS,
+#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#  See the License for the specific language governing permissions and
+#  limitations under the License.
 
 import requests
 import logging
@@ -211,10 +211,9 @@ class WMLResource:
 
     def _get_with_or_without_limit(self, url, limit, op_name, summary, pre_defined, revision=None,
                                    skip_space_project_chk=False, query_params=None, _async=False, _all=False):
-        if query_params is None:
-            params = self._client._params(skip_space_project_chk)
-        else:
-            params = query_params
+        params = self._client._params(skip_space_project_chk)
+        if query_params is not None:
+            params.update(query_params)
 
         if summary == "False":
             params.update({u'summary': u'false'})
